﻿////////////////////////////////////////////////////////////////////////////////
// Copyright (c) Elektrobit Automotive GmbH
// Alle Rechte vorbehalten. All Rights Reserved.
// Information contained herein is subject to change without notice.
// Elektrobit retains ownership and all other rights in the software and each
// component thereof.
// Any reproduction of the software or components thereof without the prior
// written permission of Elektrobit is prohibited.
////////////////////////////////////////////////////////////////////////////////

namespace MonitorRemoteViewPluginTest.Tests.RemoteViewViewModelTests
{
    using System;
    using System.Threading.Tasks;
    using FakeItEasy;
    using NUnit.Framework;

    [TestFixture]
    class AutoRefreshShould : RemoteViewViewModelTestBase
    {
        [Test]
        public void DisableAutoRefreshExecutionWhenTheMonitorIsNotConnectedToTheModel()
        {
            A.CallTo(() => ConnectionService.IsConnected).Returns(false);

            Assert.That(ViewModel.AutoRefresh.CanExecute, Is.False);
        }

        [Test]
        public void EnableAutoRefreshExecutionWhenTheMonitorIsConnectedToTheModel()
        {
            A.CallTo(() => ConnectionService.IsConnected).Returns(true);

            Assert.That(ViewModel.AutoRefresh.CanExecute, Is.True);
        }

        [Test]
        public async Task CallUiDispatcherInvokeWhenAutoRefreshIsExecuted()
        {
            await ViewModel.AutoRefresh.Execute();

            A.CallTo(() => UiDispatcher.Invoke(A<Action>.Ignored)).MustHaveHappened();
        }

        [Test]
        [TestCase((uint)3)]
        [TestCase((uint)7)]
        [TestCase((uint)10)]
        public async Task HaveTheUiDispatcherCallGetScreenshotAsyncFromScreenshotService(uint sceneNumber)
        {
            Action capturedAction = null;
            ViewModel.SelectedScene = sceneNumber;
            A.CallTo(() => UiDispatcher.Invoke(A<Action>.Ignored)).Invokes(call => capturedAction = (Action)call.Arguments[0]);

            await ViewModel.AutoRefresh.Execute();
            capturedAction();

            var sceneId = sceneNumber;
            A.CallTo(() => ContinuousScreenshotController.ToggleAsync(sceneId)).MustHaveHappened();
        }
    }
}
